summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authoralbert-github <albert.tests@gmail.com>2015-09-05 16:42:15 (GMT)
committeralbert-github <albert.tests@gmail.com>2015-09-05 16:42:15 (GMT)
commit5e11f885eea694c2ecfeae6ff5774b66eea312e4 (patch)
tree42a6656eb37327c1d76c6a9428dbdf2101761587
parent5aa4ade86499ba615da48875a9e7292ddd22c22f (diff)
downloadDoxygen-5e11f885eea694c2ecfeae6ff5774b66eea312e4.zip
Doxygen-5e11f885eea694c2ecfeae6ff5774b66eea312e4.tar.gz
Doxygen-5e11f885eea694c2ecfeae6ff5774b66eea312e4.tar.bz2
Add examples to LaTeX / PDF doxygen manual
Add the examples a shown in the HTML / CHM documentation also to the LaTeX / PDF documentation. - doc/*.doc added latexonly part referencing the example in the appendix - doc/Doxyfile silence the generation of the manual - doc/doxygen_manual.tex add the examples as appendices to the manual, by means of the subinputfrom command the parts included by refman_doc are taken from the specified directory - examples/*.cfg adjusted configuration files ("Doxyfile") to generate LaTeX output - examples/*.h and examples/*.cpp make names unique so no conflicts occur when adding all the examples - examples/CMakeLists.txt add generation of the file to be included (see strip_example.py), adjust dependencies and add the refman_doc.tex as output target - examples/input_test.cpp file added (adjusted copy of example_test.cpp) to overcome name clashes (example_test.cpp would have been included twice) - examples/strip_example.py we are only interested in the documentation files as included in the different examples, so we get those commands. The preamble will be handled by the doxygen_manual.tex and we have already an index in the doxygen_manual.tex so we don't need a separate one from each example. The module / diagram documentation is dependent on the presence of 'dot', this is reflected in the docblocks.doc, CMakeLists.txt and doxygen_manual.tex
-rw-r--r--doc/Doxyfile2
-rw-r--r--doc/autolink.doc8
-rw-r--r--doc/commands.doc58
-rw-r--r--doc/diagrams.doc7
-rw-r--r--doc/docblocks.doc32
-rw-r--r--doc/doxygen_manual.tex66
-rw-r--r--doc/grouping.doc8
-rw-r--r--examples/CMakeLists.txt134
-rw-r--r--examples/afterdoc.cfg4
-rw-r--r--examples/afterdoc.h2
-rw-r--r--examples/author.cfg4
-rw-r--r--examples/autolink.cfg4
-rw-r--r--examples/autolink.cpp38
-rw-r--r--examples/class.cfg4
-rw-r--r--examples/dbusxml.cfg4
-rw-r--r--examples/define.cfg4
-rw-r--r--examples/diagrams.cfg4
-rw-r--r--examples/docstring.cfg4
-rw-r--r--examples/enum.cfg4
-rw-r--r--examples/enum.h8
-rw-r--r--examples/example.cfg4
-rw-r--r--examples/example.cpp8
-rw-r--r--examples/example_test.cpp2
-rw-r--r--examples/file.cfg4
-rw-r--r--examples/func.cfg4
-rw-r--r--examples/func.h12
-rw-r--r--examples/group.cfg4
-rw-r--r--examples/include.cfg6
-rw-r--r--examples/include.cpp8
-rw-r--r--examples/include_test.cpp5
-rw-r--r--examples/jdstyle.cfg4
-rw-r--r--examples/jdstyle.cpp10
-rw-r--r--examples/manual.cfg4
-rw-r--r--examples/memgrp.cfg4
-rw-r--r--examples/memgrp.cpp10
-rw-r--r--examples/mux.cfg4
-rw-r--r--examples/overload.cfg4
-rw-r--r--examples/overload.cpp12
-rw-r--r--examples/page.cfg4
-rw-r--r--examples/par.cfg4
-rw-r--r--examples/par.cpp4
-rw-r--r--examples/pyexample.cfg4
-rw-r--r--examples/qtstyle.cfg4
-rw-r--r--examples/qtstyle.cpp8
-rw-r--r--examples/relates.cfg4
-rw-r--r--examples/restypedef.cfg4
-rw-r--r--examples/strip_example.py9
-rw-r--r--examples/structcmd.cfg4
-rw-r--r--examples/tclexample.cfg4
49 files changed, 416 insertions, 145 deletions
diff --git a/doc/Doxyfile b/doc/Doxyfile
index 66dfaf3..ceb6385 100644
--- a/doc/Doxyfile
+++ b/doc/Doxyfile
@@ -16,7 +16,7 @@ PROJECT_NAME = "Doxygen"
OUTPUT_DIRECTORY = ..
HTML_HEADER =
HTML_FOOTER =
-QUIET = NO
+QUIET = YES
WARNINGS = YES
DISABLE_INDEX = YES
GENERATE_TREEVIEW = YES
diff --git a/doc/autolink.doc b/doc/autolink.doc
index 9e0d35a..fe0bdea 100644
--- a/doc/autolink.doc
+++ b/doc/autolink.doc
@@ -115,6 +115,10 @@
Click <a href="examples/autolink/html/index.html">here</a>
for the corresponding HTML documentation that is generated by Doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{autolink_example}{Autolink example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\section resolving typedefs
@@ -131,6 +135,10 @@ typedef struct StructName TypeName
Click <a href="examples/restypedef/html/restypedef_8cpp.html">here</a>
for the corresponding HTML documentation that is generated by Doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{restypedef_8cpp}{Typedef example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\htmlonly
Go to the <a href="output.html">next</a> section or return to the
diff --git a/doc/commands.doc b/doc/commands.doc
index 035889f..01d069f 100644
--- a/doc/commands.doc
+++ b/doc/commands.doc
@@ -363,6 +363,10 @@ Structural indicators
Click <a href="examples/class/html/index.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{class_example}{Class example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
<hr>
\section cmddef \\def <name>
@@ -377,6 +381,11 @@ Structural indicators
Click <a href="examples/define/html/define_8h.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{define_8h}{Define example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
+
<hr>
\section cmddefgroup \\defgroup <name> (group title)
@@ -425,6 +434,10 @@ Structural indicators
Click <a href="examples/enum/html/class_test.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{class_enum___test}{Enum example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
<hr>
\section cmdexample \\example <file-name>
@@ -456,6 +469,10 @@ Structural indicators
Click <a href="examples/example/html/examples.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{example_test_8cpp-example}{Example example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\sa section \ref cmdinclude "\\include".
@@ -482,6 +499,10 @@ Structural indicators
Click <a href="examples/manual/html/index.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{extends_example}{Extends example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\sa section \ref cmdimplements "\\implements" and section
\ref cmdmemberof "\\memberof"
@@ -506,6 +527,10 @@ Structural indicators
Click <a href="examples/file/html/file_8h.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{file_example}{File example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\note In the above example \ref cfg_javadoc_autobrief "JAVADOC_AUTOBRIEF"
has been set to \c YES in the configuration file.
@@ -540,7 +565,10 @@ Structural indicators
Click <a href="examples/func/html/class_test.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
-
+ \latexonly
+ See \hyperlink{class_fn___test}{Fn example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\sa sections \ref cmdvar "\\var", \ref cmdproperty "\\property", and
\ref cmdtypedef "\\typedef".
@@ -622,6 +650,10 @@ Structural indicators
Click <a href="examples/manual/html/index.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{extends_example}{Implements example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\sa section \ref cmdextends "\\extends" and section
\ref cmdmemberof "\\memberof"
@@ -790,6 +822,10 @@ Structural indicators
Click <a href="examples/overload/html/class_test.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{class_overload___test}{Overload example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
<hr>
\section cmdpackage \\package <name>
@@ -814,6 +850,10 @@ Structural indicators
Click <a href="examples/page/html/pages.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{page_example}{Page example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\par Note:
The \<name\> argument consists of a combination of letters and number
@@ -970,6 +1010,10 @@ Structural indicators
Click <a href="examples/relates/html/class_string.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{class_string}{Relates example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
<hr>
\section cmdrelated \\related <name>
@@ -1121,6 +1165,10 @@ Section indicators
Click <a href="examples/author/html/class_some_nice_class.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{class_some_nice_class}{Author example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
<hr>
\section cmdauthors \\authors { list of authors }
@@ -1464,6 +1512,10 @@ ALIASES = "english=\if english" \
Click <a href="examples/par/html/class_test.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{class_par___test}{Par example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
<hr>
\section cmdparam \\param [(dir)] <parameter-name> { parameter description }
@@ -2070,6 +2122,10 @@ Commands for displaying examples
Click <a href="examples/include/html/example.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{include_example}{Include example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
Alternatively, the \ref cmdsnippet "\\snippet" command can be used to
include only a fragment of a source file. For this to work the
diff --git a/doc/diagrams.doc b/doc/diagrams.doc
index c87337b..7d497bd 100644
--- a/doc/diagrams.doc
+++ b/doc/diagrams.doc
@@ -142,6 +142,13 @@ Click <a href="examples/diagrams/html/index.html">here</a>
for the corresponding HTML documentation that is generated by doxygen<br/>
(<code>EXTRACT_ALL</code> = <code>YES</code> is used here).
\endhtmlonly
+\latexonly
+\IfFileExists{../html/examples/diagrams/latex/refman_doc.tex}
+{
+See \hyperlink{diagrams_example}{Diagrams example}
+for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+} {}
+\endlatexonly
\htmlonly
<br><br>
diff --git a/doc/docblocks.doc b/doc/docblocks.doc
index 3b42506..7f91db5 100644
--- a/doc/docblocks.doc
+++ b/doc/docblocks.doc
@@ -262,6 +262,10 @@ Here is an example of the use of these comment blocks:
Click <a href="examples/afterdoc/html/class_test.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{afterdoc_example}{After Block example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\warning These blocks can only be used to document \e members and \e parameters.
They cannot be used to document files, classes, unions, structs,
@@ -278,6 +282,10 @@ Here is an example of a documented piece of C++ code using the Qt style:
Click <a href="examples/qtstyle/html/class_test.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{qtstyle_example}{QT Style example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
The brief descriptions are included in the member overview of a
class, namespace or file and are printed using a small italic font
@@ -308,6 +316,10 @@ JavaDoc style and \ref cfg_javadoc_autobrief "JAVADOC_AUTOBRIEF" set to YES:
Click <a href="examples/jdstyle/html/class_test.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{jdstyle_example}{Javadoc Style example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
Similarly, if one wishes the first sentence of a Qt style documentation
block to automatically be treated as a brief description, one may set
@@ -384,6 +396,10 @@ using structural commands:
Click <a href="examples/structcmd/html/structcmd_8h.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{structcmd_example}{Structural Commands example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
Because each comment block in the example above contains a structural command, all
the comment blocks could be moved to another location or input file
@@ -424,6 +440,10 @@ and assume they have to be represented in a preformatted way.
Click <a href="examples/docstring/html/index.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{python_example}{Python Docstring example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
Note that in this case none of doxygen's \ref cmd_intro "special commands"
are supported.
@@ -440,6 +460,10 @@ Here is the same example again but now using doxygen style comments:
Click <a href="examples/pyexample/html/index.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{py_example}{Python example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
Since python looks more like Java than like C or C++, you should set
\ref cfg_optimize_output_java "OPTIMIZE_OUTPUT_JAVA" to \c YES in the
@@ -465,6 +489,10 @@ Here is an example VHDL file with doxygen comments:
Click <a href="examples/mux/html/index.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{vhdl_example}{VHDL example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
To get proper looking output you need to set
\ref cfg_optimize_output_vhdl "OPTIMIZE_OUTPUT_VHDL" to \c YES in the
@@ -574,6 +602,10 @@ Following is an example using doxygen style comments:
Click <a href="examples/tclexample/html/index.html">here</a>
for the corresponding HTML documentation that is generated by doxygen.
\endhtmlonly
+ \latexonly
+ See \hyperlink{tcl_example}{TCL example}
+ for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+ \endlatexonly
\section docstructure Anatomy of a comment block
diff --git a/doc/doxygen_manual.tex b/doc/doxygen_manual.tex
index 16bc4be..9f96adf 100644
--- a/doc/doxygen_manual.tex
+++ b/doc/doxygen_manual.tex
@@ -29,6 +29,8 @@
\usepackage{textcomp}
\usepackage[nointegrals]{wasysym}
\usepackage{alltt}
+\usepackage{import}
+\usepackage[titletoc]{appendix}
\usepackage{ifpdf}
\ifpdf
\usepackage[pdftex,
@@ -117,5 +119,69 @@ Written by Dimitri van Heesch\\[2ex]
\chapter{Doxygen's internals}\label{arch}\hypertarget{arch}{}\input{arch}
\chapter{Perl Module Output format}\label{perlmod}\hypertarget{perlmod}{}\input{perlmod}
\chapter{Internationalization}\label{langhowto}\hypertarget{langhowto}{}\input{langhowto}
+\renewcommand{\thepart}{}
+\part{Appendices}
+\appendix
+%mean that subinputfrom requires a / at the end of the path
+\chapter{Autolink Example}\label{autolink_example}\hypertarget{autolink_example}{}
+\subinputfrom{../html/examples/autolink/latex/}{refman_doc}
+\chapter{Resolving Typedef Example}\label{restypedef_example}\hypertarget{restypedef_example}{}
+\subinputfrom{../html/examples/restypedef/latex/}{refman_doc}
+
+\IfFileExists{../html/examples/diagrams/latex/refman_doc.tex}
+{
+ \chapter{Diagrams Example}\label{diagrams_example}\hypertarget{diagrams_example}{}
+ \subinputfrom{../html/examples/diagrams/latex/}{refman_doc}
+}{}
+
+\chapter{Modules Example}\label{modules_example}\hypertarget{modules_example}{}
+\subinputfrom{../html/examples/group/latex/}{refman_doc}
+\chapter{Member Groups Example}\label{memgrp_example}\hypertarget{memgrp_example}{}
+\subinputfrom{../html/examples/memgrp/latex/}{refman_doc}
+\chapter{After Block Example}\label{afterdoc_example}\hypertarget{afterdoc_example}{}
+\subinputfrom{../html/examples/afterdoc/latex/}{refman_doc}
+\chapter{QT Style Example}\label{qtstyle_example}\hypertarget{qtstyle_example}{}
+\subinputfrom{../html/examples/qtstyle/latex/}{refman_doc}
+\chapter{Javadoc Style Example}\label{jdstyle_example}\hypertarget{jdstyle_example}{}
+\subinputfrom{../html/examples/jdstyle/latex/}{refman_doc}
+\chapter{Structural Commands Example}\label{structcmd_example}\hypertarget{structcmd_example}{}
+\subinputfrom{../html/examples/structcmd/latex/}{refman_doc}
+\chapter{Python Docstring Example}\label{python_example}\hypertarget{python_example}{}
+\subinputfrom{../html/examples/docstring/latex/}{refman_doc}
+\chapter{Python Example}\label{py_example}\hypertarget{py_example}{}
+\subinputfrom{../html/examples/pyexample/latex/}{refman_doc}
+\chapter{VHDL Example}\label{vhdl_example}\hypertarget{vhdl_example}{}
+\subinputfrom{../html/examples/mux/latex/}{refman_doc}
+\chapter{Tcl Example}\label{tcl_example}\hypertarget{tcl_example}{}
+\subinputfrom{../html/examples/tclexample/latex/}{refman_doc}
+
+\chapter{Class Example}\label{class_example}\hypertarget{class_example}{}
+\subinputfrom{../html/examples/class/latex/}{refman_doc}
+\chapter{Define Example}\label{define_example}\hypertarget{define_example}{}
+\subinputfrom{../html/examples/define/latex/}{refman_doc}
+\chapter{Enum Example}\label{enum_example}\hypertarget{enum_example}{}
+\subinputfrom{../html/examples/enum/latex/}{refman_doc}
+\chapter{Example Example}\label{example_example}\hypertarget{example_example}{}
+\subinputfrom{../html/examples/example/latex/}{refman_doc}
+\chapter{Extends/Implements Example}\label{extends_example}\hypertarget{extends_example}{}
+\subinputfrom{../html/examples/manual/latex/}{refman_doc}
+\chapter{File Example}\label{file_example}\hypertarget{file_example}{}
+\subinputfrom{../html/examples/file/latex/}{refman_doc}
+\chapter{Fn Example}\label{fn_example}\hypertarget{fn_example}{}
+\subinputfrom{../html/examples/func/latex/}{refman_doc}
+\chapter{Overload Example}\label{overload_example}\hypertarget{overload_example}{}
+\subinputfrom{../html/examples/overload/latex/}{refman_doc}
+\chapter{Page Example}\label{page_example}\hypertarget{page_example}{}
+\subinputfrom{../html/examples/page/latex/}{refman_doc}
+\chapter{Relates Example}\label{relates_example}\hypertarget{relates_example}{}
+\subinputfrom{../html/examples/relates/latex/}{refman_doc}
+\chapter{Author Example}\label{author_example}\hypertarget{author_example}{}
+\subinputfrom{../html/examples/author/latex/}{refman_doc}
+\chapter{Par Example}\label{par_example}\hypertarget{par_example}{}
+\subinputfrom{../html/examples/par/latex/}{refman_doc}
+\chapter{Include Example}\label{include_example}\hypertarget{include_example}{}
+\subinputfrom{../html/examples/include/latex/}{refman_doc}
+
+
\printindex
\end{document}
diff --git a/doc/grouping.doc b/doc/grouping.doc
index a6fdf43..f369998 100644
--- a/doc/grouping.doc
+++ b/doc/grouping.doc
@@ -141,6 +141,10 @@ in .c files without having to duplicate the hierarchy exactly.
Click <a href="examples/group/html/modules.html">here</a>
for the corresponding HTML documentation that is generated by Doxygen.
\endhtmlonly
+\latexonly
+See \hyperlink{modules_example}{Modules example}
+for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+\endlatexonly
\section memgroup Member Groups
@@ -194,6 +198,10 @@ documentation of the class.
Click <a href="examples/memgrp/html/class_test.html">here</a>
for the corresponding HTML documentation that is generated by Doxygen.
\endhtmlonly
+\latexonly
+See \hyperlink{memgrp_example}{Member Groups example}
+for the corresponding \mbox{\LaTeX} documentation that is generated by doxygen.
+\endlatexonly
Here Group1 is displayed as a subsection of the "Public Members". And
Group2 is a separate section because it contains members with
diff --git a/examples/CMakeLists.txt b/examples/CMakeLists.txt
index e7b61a1..24bcbfa 100644
--- a/examples/CMakeLists.txt
+++ b/examples/CMakeLists.txt
@@ -53,171 +53,197 @@ add_custom_target(examples
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen class.cfg
- DEPENDS doxygen class.h class.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/class/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/class/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/class/latex/refman_doc.tex
+ DEPENDS doxygen class.h class.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/class/html/index.html ${PROJECT_BINARY_DIR}/html/examples/class/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen define.cfg
- DEPENDS doxygen define.h define.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/define/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/define/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/define/latex/refman_doc.tex
+ DEPENDS doxygen define.h define.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/define/html/index.html ${PROJECT_BINARY_DIR}/html/examples/define/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen enum.cfg
- DEPENDS doxygen enum.h enum.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/enum/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/enum/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/enum/latex/refman_doc.tex
+ DEPENDS doxygen enum.h enum.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/enum/html/index.html ${PROJECT_BINARY_DIR}/html/examples/enum/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen file.cfg
- DEPENDS doxygen file.h file.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/file/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/file/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/file/latex/refman_doc.tex
+ DEPENDS doxygen file.h file.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/file/html/index.html ${PROJECT_BINARY_DIR}/html/examples/file/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen func.cfg
- DEPENDS doxygen func.h func.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/func/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/func/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/func/latex/refman_doc.tex
+ DEPENDS doxygen func.h func.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/func/html/index.html ${PROJECT_BINARY_DIR}/html/examples/func/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen page.cfg
- DEPENDS doxygen page.doc page.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/page/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/page/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/page/latex/refman_doc.tex
+ DEPENDS doxygen page.doc page.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/page/html/index.html ${PROJECT_BINARY_DIR}/html/examples/page/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen relates.cfg
- DEPENDS doxygen relates.cpp relates.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/relates/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/relates/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/relates/latex/refman_doc.tex
+ DEPENDS doxygen relates.cpp relates.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/relates/html/index.html ${PROJECT_BINARY_DIR}/html/examples/relates/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen author.cfg
- DEPENDS doxygen author.cpp author.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/author/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/author/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/author/latex/refman_doc.tex
+ DEPENDS doxygen author.cpp author.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/author/html/index.html ${PROJECT_BINARY_DIR}/html/examples/author/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen par.cfg
- DEPENDS doxygen par.cpp par.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/par/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/par/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/par/latex/refman_doc.tex
+ DEPENDS doxygen par.cpp par.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/par/html/index.html ${PROJECT_BINARY_DIR}/html/examples/par/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen overload.cfg
- DEPENDS doxygen overload.cpp overload.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/overload/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/overload/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/overload/latex/refman_doc.tex
+ DEPENDS doxygen overload.cpp overload.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/overload/html/index.html ${PROJECT_BINARY_DIR}/html/examples/overload/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen example.cfg
- DEPENDS doxygen example.cpp example_test.cpp example.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/example/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/example/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/example/latex/refman_doc.tex
+ DEPENDS doxygen example.cpp example_test.cpp example.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/example/html/index.html ${PROJECT_BINARY_DIR}/html/examples/example/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen include.cfg
- DEPENDS doxygen include.cpp example_test.cpp include.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/include/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/include/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/include/latex/refman_doc.tex
+ DEPENDS doxygen include.cpp include_test.cpp include.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/include/html/index.html ${PROJECT_BINARY_DIR}/html/examples/include/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen qtstyle.cfg
- DEPENDS doxygen qtstyle.cpp qtstyle.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/qtstyle/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/qtstyle/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/qtstyle/latex/refman_doc.tex
+ DEPENDS doxygen qtstyle.cpp qtstyle.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/qtstyle/html/index.html ${PROJECT_BINARY_DIR}/html/examples/qtstyle/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen jdstyle.cfg
- DEPENDS doxygen jdstyle.cpp jdstyle.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/jdstyle/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/jdstyle/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/jdstyle/latex/refman_doc.tex
+ DEPENDS doxygen jdstyle.cpp jdstyle.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/jdstyle/html/index.html ${PROJECT_BINARY_DIR}/html/examples/jdstyle/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen structcmd.cfg
- DEPENDS doxygen structcmd.h structcmd.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/structcmd/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/structcmd/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/structcmd/latex/refman_doc.tex
+ DEPENDS doxygen structcmd.h structcmd.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/structcmd/html/index.html ${PROJECT_BINARY_DIR}/html/examples/structcmd/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen autolink.cfg
- DEPENDS doxygen autolink.cpp autolink.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/autolink/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/autolink/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/autolink/latex/refman_doc.tex
+ DEPENDS doxygen autolink.cpp autolink.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/autolink/html/index.html ${PROJECT_BINARY_DIR}/html/examples/autolink/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen tag.cfg
- DEPENDS doxygen tag.cpp tag.cfg ${PROJECT_BINARY_DIR}/html/examples/example/html/index.html
+ DEPENDS doxygen tag.cpp tag.cfg ${PROJECT_BINARY_DIR}/html/examples/example/html/index.html ${TOP}/examples/strip_example.py
OUTPUT ${PROJECT_BINARY_DIR}/html/examples/tag/html/index.html
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen restypedef.cfg
- DEPENDS doxygen restypedef.cpp restypedef.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/restypedef/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/restypedef/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/restypedef/latex/refman_doc.tex
+ DEPENDS doxygen restypedef.cpp restypedef.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/restypedef/html/index.html ${PROJECT_BINARY_DIR}/html/examples/restypedef/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen afterdoc.cfg
- DEPENDS doxygen afterdoc.h afterdoc.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/afterdoc/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/afterdoc/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/afterdoc/latex/refman_doc.tex
+ DEPENDS doxygen afterdoc.h afterdoc.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/afterdoc/html/index.html ${PROJECT_BINARY_DIR}/html/examples/afterdoc/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen templ.cfg
- DEPENDS doxygen templ.cpp templ.cfg
+ DEPENDS doxygen templ.cpp templ.cfg ${TOP}/examples/strip_example.py
OUTPUT ${PROJECT_BINARY_DIR}/html/examples/template/html/index.html
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen group.cfg
- DEPENDS doxygen group.cpp group.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/group/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/group/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/group/latex/refman_doc.tex
+ DEPENDS doxygen group.cpp group.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/group/html/index.html ${PROJECT_BINARY_DIR}/html/examples/group/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen memgrp.cfg
- DEPENDS doxygen memgrp.cpp memgrp.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/memgrp/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/memgrp/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/memgrp/latex/refman_doc.tex
+ DEPENDS doxygen memgrp.cpp memgrp.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/memgrp/html/index.html ${PROJECT_BINARY_DIR}/html/examples/memgrp/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen pyexample.cfg
- DEPENDS doxygen pyexample.py pyexample.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/pyexample/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/pyexample/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/pyexample/latex/refman_doc.tex
+ DEPENDS doxygen pyexample.py pyexample.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/pyexample/html/index.html ${PROJECT_BINARY_DIR}/html/examples/pyexample/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen tclexample.cfg
- DEPENDS doxygen tclexample.tcl tclexample.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/tclexample/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/tclexample/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/tclexample/latex/refman_doc.tex
+ DEPENDS doxygen tclexample.tcl tclexample.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/tclexample/html/index.html ${PROJECT_BINARY_DIR}/html/examples/tclexample/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen mux.cfg
- DEPENDS doxygen mux.vhdl mux.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/mux/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/mux/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/mux/latex/refman_doc.tex
+ DEPENDS doxygen mux.vhdl mux.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/mux/html/index.html ${PROJECT_BINARY_DIR}/html/examples/mux/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen manual.cfg
- DEPENDS doxygen manual.c manual.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/manual/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/manual/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/manual/latex/refman_doc.tex
+ DEPENDS doxygen manual.c manual.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/manual/html/index.html ${PROJECT_BINARY_DIR}/html/examples/manual/latex/refman_doc.tex
)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen docstring.cfg
- DEPENDS doxygen docstring.py docstring.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/docstring/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/docstring/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/docstring/latex/refman_doc.tex
+ DEPENDS doxygen docstring.py docstring.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/docstring/html/index.html ${PROJECT_BINARY_DIR}/html/examples/docstring/latex/refman_doc.tex
)
if (DOT)
add_custom_command(
COMMAND ${EXECUTABLE_OUTPUT_PATH}/doxygen diagrams.cfg
- DEPENDS doxygen diagrams_a.h diagrams_b.h diagrams_c.h diagrams_d.h diagrams_e.h diagrams.cfg
- OUTPUT ${PROJECT_BINARY_DIR}/html/examples/diagrams/html/index.html
+ COMMAND ${PYTHON_EXECUTABLE} ${TOP}/examples/strip_example.py < ${PROJECT_BINARY_DIR}/html/examples/diagrams/latex/refman.tex > ${PROJECT_BINARY_DIR}/html/examples/diagrams/latex/refman_doc.tex
+ DEPENDS doxygen diagrams_a.h diagrams_b.h diagrams_c.h diagrams_d.h diagrams_e.h diagrams.cfg ${TOP}/examples/strip_example.py
+ OUTPUT ${PROJECT_BINARY_DIR}/html/examples/diagrams/html/index.html ${PROJECT_BINARY_DIR}/html/examples/diagrams/latex/refman_doc.tex
)
endif(DOT)
diff --git a/examples/afterdoc.cfg b/examples/afterdoc.cfg
index 37bb12d..9ec54fd 100644
--- a/examples/afterdoc.cfg
+++ b/examples/afterdoc.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "AfterDocs"
OUTPUT_DIRECTORY = ../html/examples/afterdoc
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = afterdoc.h
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/afterdoc.h b/examples/afterdoc.h
index 907dabe..b3200a8 100644
--- a/examples/afterdoc.h
+++ b/examples/afterdoc.h
@@ -1,6 +1,6 @@
/*! A test class */
-class Test
+class Afterdoc_Test
{
public:
/** An enum type.
diff --git a/examples/author.cfg b/examples/author.cfg
index c7b942c..2fafbfe 100644
--- a/examples/author.cfg
+++ b/examples/author.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Author Command"
OUTPUT_DIRECTORY = ../html/examples/author
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = author.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/autolink.cfg b/examples/autolink.cfg
index 287b37d..68e5192 100644
--- a/examples/autolink.cfg
+++ b/examples/autolink.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Automatic link generation"
OUTPUT_DIRECTORY = ../html/examples/autolink
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = autolink.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/autolink.cpp b/examples/autolink.cpp
index e028f22..71a3c85 100644
--- a/examples/autolink.cpp
+++ b/examples/autolink.cpp
@@ -1,33 +1,33 @@
/*! \file autolink.cpp
Testing automatic link generation.
- A link to a member of the Test class: Test::member,
+ A link to a member of the Autolink_Test class: Autolink_Test::member,
More specific links to the each of the overloaded members:
- Test::member(int) and Test#member(int,int)
+ Autolink_Test::member(int) and Autolink_Test#member(int,int)
- A link to a protected member variable of Test: Test#var,
+ A link to a protected member variable of Autolink_Test: Autolink_Test#var,
A link to the global enumeration type #GlobEnum.
A link to the define #ABS(x).
- A link to the destructor of the Test class: Test::~Test,
+ A link to the destructor of the Autolink_Test class: Autolink_Test::~Autolink_Test,
A link to the typedef ::B.
- A link to the enumeration type Test::EType
+ A link to the enumeration type Autolink_Test::EType
- A link to some enumeration values Test::Val1 and ::GVal2
+ A link to some enumeration values Autolink_Test::Val1 and ::GVal2
*/
/*!
- Since this documentation block belongs to the class Test no link to
- Test is generated.
+ Since this documentation block belongs to the class Autolink_Test no link to
+ Autolink_Test is generated.
- Two ways to link to a constructor are: #Test and Test().
+ Two ways to link to a constructor are: #Autolink_Test and Autolink_Test().
- Links to the destructor are: #~Test and ~Test().
+ Links to the destructor are: #~Autolink_Test and ~Autolink_Test().
A link to a member in this class: member().
@@ -46,19 +46,19 @@
A link to the enumeration type #EType.
- A link to some enumeration values: \link Test::Val1 Val1 \endlink and ::GVal1.
+ A link to some enumeration values: \link Autolink_Test::Val1 Val1 \endlink and ::GVal1.
And last but not least a link to a file: autolink.cpp.
\sa Inside a see also section any word is checked, so EType,
- Val1, GVal1, ~Test and member will be replaced by links in HTML.
+ Val1, GVal1, ~Autolink_Test and member will be replaced by links in HTML.
*/
-class Test
+class Autolink_Test
{
public:
- Test(); //!< constructor
- ~Test(); //!< destructor
+ Autolink_Test(); //!< constructor
+ ~Autolink_Test(); //!< destructor
void member(int); /**< A member function. Details. */
void member(int,int); /**< An overloaded member function. Details */
@@ -73,10 +73,10 @@ class Test
};
/*! details. */
-Test::Test() { }
+Autolink_Test::Autolink_Test() { }
/*! details. */
-Test::~Test() { }
+Autolink_Test::~Autolink_Test() { }
/*! A global variable. */
int globVar;
@@ -92,8 +92,8 @@ enum GlobEnum {
*/
#define ABS(x) (((x)>0)?(x):-(x))
-typedef Test B;
+typedef Autolink_Test B;
-/*! \fn typedef Test B
+/*! \fn typedef Autolink_Test B
* A type definition.
*/
diff --git a/examples/class.cfg b/examples/class.cfg
index 579cc75..515689f 100644
--- a/examples/class.cfg
+++ b/examples/class.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Class Command"
OUTPUT_DIRECTORY = ../html/examples/class
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = class.h
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/dbusxml.cfg b/examples/dbusxml.cfg
index 7b70772..d964ea2 100644
--- a/examples/dbusxml.cfg
+++ b/examples/dbusxml.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "DBusXMLDocs"
OUTPUT_DIRECTORY = ../html/examples/dbusxml
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -10,3 +10,5 @@ JAVADOC_AUTOBRIEF = YES
EXTRACT_ALL = YES
SEARCHENGINE = NO
EXTENSION_MAPPING = xml=dbusxml
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/define.cfg b/examples/define.cfg
index 8a12da8..491c1eb 100644
--- a/examples/define.cfg
+++ b/examples/define.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Define Command"
OUTPUT_DIRECTORY = ../html/examples/define
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -9,3 +9,5 @@ ENABLE_PREPROCESSING = YES
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/diagrams.cfg b/examples/diagrams.cfg
index 5301786..19cbbc8 100644
--- a/examples/diagrams.cfg
+++ b/examples/diagrams.cfg
@@ -2,7 +2,7 @@ PROJECT_NAME = "Diagrams"
OUTPUT_DIRECTORY = ../html/examples/diagrams
HAVE_DOT = YES
EXTRACT_ALL = YES
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -12,3 +12,5 @@ FILE_PATTERNS = diagrams_*.h
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/docstring.cfg b/examples/docstring.cfg
index bd65500..60b089e 100644
--- a/examples/docstring.cfg
+++ b/examples/docstring.cfg
@@ -1,7 +1,7 @@
PROJECT_NAME = "Python"
OUTPUT_DIRECTORY = ../html/examples/docstring
EXTRACT_ALL = YES
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
OPTIMIZE_OUTPUT_JAVA = YES
@@ -9,3 +9,5 @@ INPUT = docstring.py
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/enum.cfg b/examples/enum.cfg
index 7732be8..74bb651 100644
--- a/examples/enum.cfg
+++ b/examples/enum.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Enum Command"
OUTPUT_DIRECTORY = ../html/examples/enum
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = enum.h
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/enum.h b/examples/enum.h
index 4c54fab..ab7ffa6 100644
--- a/examples/enum.h
+++ b/examples/enum.h
@@ -1,4 +1,4 @@
-class Test
+class Enum_Test
{
public:
enum TEnum { Val1, Val2 };
@@ -11,14 +11,14 @@ class Test
};
};
-/*! \class Test
+/*! \class Enum_Test
* The class description.
*/
-/*! \enum Test::TEnum
+/*! \enum Enum_Test::TEnum
* A description of the enum type.
*/
-/*! \var Test::TEnum Test::Val1
+/*! \var Enum_Test::TEnum Enum_Test::Val1
* The description of the first enum value.
*/
diff --git a/examples/example.cfg b/examples/example.cfg
index f57e4ba..c55c6b9 100644
--- a/examples/example.cfg
+++ b/examples/example.cfg
@@ -1,7 +1,7 @@
PROJECT_NAME = "Example Command"
OUTPUT_DIRECTORY = ../html/examples/example
#GENERATE_TAGFILE = example.tag
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -10,3 +10,5 @@ EXAMPLE_PATH = example_test.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/example_test.cpp b/examples/example_test.cpp
index a7e1643..cefee43 100644
--- a/examples/example_test.cpp
+++ b/examples/example_test.cpp
@@ -1,5 +1,5 @@
void main()
{
- Test t;
+ Example_Test t;
t.example();
}
diff --git a/examples/file.cfg b/examples/file.cfg
index e622c1e..6b20b87 100644
--- a/examples/file.cfg
+++ b/examples/file.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "File Command"
OUTPUT_DIRECTORY = ../html/examples/file
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = file.h
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/func.cfg b/examples/func.cfg
index 4929f66..c0feb0f 100644
--- a/examples/func.cfg
+++ b/examples/func.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Fn Command"
OUTPUT_DIRECTORY = ../html/examples/func
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = func.h
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/func.h b/examples/func.h
index b335448..cc0ac38 100644
--- a/examples/func.h
+++ b/examples/func.h
@@ -1,18 +1,18 @@
-class Test
+class Fn_Test
{
public:
const char *member(char,int) throw(std::out_of_range);
};
-const char *Test::member(char c,int n) throw(std::out_of_range) {}
+const char *Fn_Test::member(char c,int n) throw(std::out_of_range) {}
-/*! \class Test
- * \brief Test class.
+/*! \class Fn_Test
+ * \brief Fn_Test class.
*
- * Details about Test.
+ * Details about Fn_Test.
*/
-/*! \fn const char *Test::member(char c,int n)
+/*! \fn const char *Fn_Test::member(char c,int n)
* \brief A member function.
* \param c a character.
* \param n an integer.
diff --git a/examples/group.cfg b/examples/group.cfg
index 7882713..83911b8 100644
--- a/examples/group.cfg
+++ b/examples/group.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Grouping"
OUTPUT_DIRECTORY = ../html/examples/group
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = group.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/include.cfg b/examples/include.cfg
index 4ecdf8f..abaecc6 100644
--- a/examples/include.cfg
+++ b/examples/include.cfg
@@ -1,11 +1,13 @@
PROJECT_NAME = "Include Command"
OUTPUT_DIRECTORY = ../html/examples/include
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
INPUT = include.cpp
-EXAMPLE_PATH = example_test.cpp
+EXAMPLE_PATH = include_test.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/include_test.cpp b/examples/include_test.cpp
new file mode 100644
index 0000000..df8634a
--- /dev/null
+++ b/examples/include_test.cpp
@@ -0,0 +1,5 @@
+void main()
+{
+ Include_Test t;
+ t.example();
+}
diff --git a/examples/jdstyle.cfg b/examples/jdstyle.cfg
index 15eccee..0ddc0d9 100644
--- a/examples/jdstyle.cfg
+++ b/examples/jdstyle.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "JavaDoc Style"
OUTPUT_DIRECTORY = ../html/examples/jdstyle
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = jdstyle.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/jdstyle.cpp b/examples/jdstyle.cpp
index bd8b9a7..04885e4 100644
--- a/examples/jdstyle.cpp
+++ b/examples/jdstyle.cpp
@@ -2,7 +2,7 @@
* A test class. A more elaborate class description.
*/
-class Test
+class Javadoc_Test
{
public:
@@ -23,20 +23,20 @@ class Test
* A constructor.
* A more elaborate description of the constructor.
*/
- Test();
+ Javadoc_Test();
/**
* A destructor.
* A more elaborate description of the destructor.
*/
- ~Test();
+ ~Javadoc_Test();
/**
* a normal member taking two arguments and returning an integer value.
* @param a an integer argument.
* @param s a constant character pointer.
- * @see Test()
- * @see ~Test()
+ * @see Javadoc_Test()
+ * @see ~Javadoc_Test()
* @see testMeToo()
* @see publicVar()
* @return The test results
diff --git a/examples/manual.cfg b/examples/manual.cfg
index 75d1fc5..07040d9 100644
--- a/examples/manual.cfg
+++ b/examples/manual.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Manual inheritance and membership"
OUTPUT_DIRECTORY = ../html/examples/manual
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -14,3 +14,5 @@ INLINE_SOURCES = YES
REFERENCED_BY_RELATION = YES
REFERENCES_RELATION = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/memgrp.cfg b/examples/memgrp.cfg
index dea742c..d609778 100644
--- a/examples/memgrp.cfg
+++ b/examples/memgrp.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Member Grouping"
OUTPUT_DIRECTORY = ../html/examples/memgrp
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -9,3 +9,5 @@ QUIET = YES
DISTRIBUTE_GROUP_DOC = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/memgrp.cpp b/examples/memgrp.cpp
index 77f03a4..9a24774 100644
--- a/examples/memgrp.cpp
+++ b/examples/memgrp.cpp
@@ -1,5 +1,5 @@
/** A class. Details */
-class Test
+class Memgrp_Test
{
public:
//@{
@@ -15,17 +15,17 @@ class Test
void func2InGroup2();
};
-void Test::func1InGroup1() {}
-void Test::func2InGroup1() {}
+void Memgrp_Test::func1InGroup1() {}
+void Memgrp_Test::func2InGroup1() {}
/** @name Group2
* Description of group 2.
*/
///@{
/** Function 2 in group 2. Details. */
-void Test::func2InGroup2() {}
+void Memgrp_Test::func2InGroup2() {}
/** Function 1 in group 2. Details. */
-void Test::func1InGroup2() {}
+void Memgrp_Test::func1InGroup2() {}
///@}
/*! \file
diff --git a/examples/mux.cfg b/examples/mux.cfg
index 11aa7ca..861f2f6 100644
--- a/examples/mux.cfg
+++ b/examples/mux.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = Mux
OUTPUT_DIRECTORY = ../html/examples/mux
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -14,3 +14,5 @@ INHERIT_DOCS = NO
SEARCHENGINE = NO
ENABLE_PREPROCESSING = NO
EXTRACT_PACKAGE = YES
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/overload.cfg b/examples/overload.cfg
index 9677065..71ebcc5 100644
--- a/examples/overload.cfg
+++ b/examples/overload.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Overloaded Command"
OUTPUT_DIRECTORY = ../html/examples/overload
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -9,3 +9,5 @@ INPUT = overload.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/overload.cpp b/examples/overload.cpp
index 02bcced..7aeb1cb 100644
--- a/examples/overload.cpp
+++ b/examples/overload.cpp
@@ -1,25 +1,25 @@
-class Test
+class Overload_Test
{
public:
void drawRect(int,int,int,int);
void drawRect(const Rect &r);
};
-void Test::drawRect(int x,int y,int w,int h) {}
-void Test::drawRect(const Rect &r) {}
+void Overload_Test::drawRect(int x,int y,int w,int h) {}
+void Overload_Test::drawRect(const Rect &r) {}
-/*! \class Test
+/*! \class Overload_Test
* \brief A short description.
*
* More text.
*/
-/*! \fn void Test::drawRect(int x,int y,int w,int h)
+/*! \fn void Overload_Test::drawRect(int x,int y,int w,int h)
* This command draws a rectangle with a left upper corner at ( \a x , \a y ),
* width \a w and height \a h.
*/
/*!
- * \overload void Test::drawRect(const Rect &r)
+ * \overload void Overload_Test::drawRect(const Rect &r)
*/
diff --git a/examples/page.cfg b/examples/page.cfg
index 980cb17..972368a 100644
--- a/examples/page.cfg
+++ b/examples/page.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Page Command"
OUTPUT_DIRECTORY = ../html/examples/page
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = page.doc
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/par.cfg b/examples/par.cfg
index 5be0e03..fe4be84 100644
--- a/examples/par.cfg
+++ b/examples/par.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Par Command"
OUTPUT_DIRECTORY = ../html/examples/par
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = par.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/par.cpp b/examples/par.cpp
index 6fd2c4e..cae55d7 100644
--- a/examples/par.cpp
+++ b/examples/par.cpp
@@ -1,4 +1,4 @@
-/*! \class Test
+/*! \class Par_Test
* Normal text.
*
* \par User defined paragraph:
@@ -17,4 +17,4 @@
* More normal text.
*/
-class Test {};
+class Par_Test {};
diff --git a/examples/pyexample.cfg b/examples/pyexample.cfg
index 9b44984..4569425 100644
--- a/examples/pyexample.cfg
+++ b/examples/pyexample.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Python"
OUTPUT_DIRECTORY = ../html/examples/pyexample
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
OPTIMIZE_OUTPUT_JAVA = YES
@@ -8,3 +8,5 @@ INPUT = pyexample.py
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/qtstyle.cfg b/examples/qtstyle.cfg
index beae9e4..1516c7e 100644
--- a/examples/qtstyle.cfg
+++ b/examples/qtstyle.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Qt Style"
OUTPUT_DIRECTORY = ../html/examples/qtstyle
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = qtstyle.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/qtstyle.cpp b/examples/qtstyle.cpp
index e24d541..8b55c8d 100644
--- a/examples/qtstyle.cpp
+++ b/examples/qtstyle.cpp
@@ -3,7 +3,7 @@
A more elaborate class description.
*/
-class Test
+class QTstyle_Test
{
public:
@@ -25,20 +25,20 @@ class Test
/*!
A more elaborate description of the constructor.
*/
- Test();
+ QTstyle_Test();
//! A destructor.
/*!
A more elaborate description of the destructor.
*/
- ~Test();
+ ~QTstyle_Test();
//! A normal member taking two arguments and returning an integer value.
/*!
\param a an integer argument.
\param s a constant character pointer.
\return The test results
- \sa Test(), ~Test(), testMeToo() and publicVar()
+ \sa QTstyle_Test(), ~QTstyle_Test(), testMeToo() and publicVar()
*/
int testMe(int a,const char *s);
diff --git a/examples/relates.cfg b/examples/relates.cfg
index 9155a7e..89f46da 100644
--- a/examples/relates.cfg
+++ b/examples/relates.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Relates Command"
OUTPUT_DIRECTORY = ../html/examples/relates
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = relates.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/restypedef.cfg b/examples/restypedef.cfg
index 6282a64..63d2ea5 100644
--- a/examples/restypedef.cfg
+++ b/examples/restypedef.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Resolving Typedefs"
OUTPUT_DIRECTORY = ../html/examples/restypedef
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = restypedef.cpp
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/strip_example.py b/examples/strip_example.py
new file mode 100644
index 0000000..d88b893
--- /dev/null
+++ b/examples/strip_example.py
@@ -0,0 +1,9 @@
+import sys
+do_print = False
+for line in sys.stdin:
+ if line.startswith("%--- Begin generated contents ---"):
+ do_print = True
+ elif line.startswith("%--- End generated contents ---"):
+ do_print = False
+ elif do_print:
+ sys.stdout.write(line)
diff --git a/examples/structcmd.cfg b/examples/structcmd.cfg
index d60cfcf..d510d27 100644
--- a/examples/structcmd.cfg
+++ b/examples/structcmd.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Structural commands"
OUTPUT_DIRECTORY = ../html/examples/structcmd
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -8,3 +8,5 @@ INPUT = structcmd.h
QUIET = YES
JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/tclexample.cfg b/examples/tclexample.cfg
index e51f4fc..e151d14 100644
--- a/examples/tclexample.cfg
+++ b/examples/tclexample.cfg
@@ -1,6 +1,6 @@
PROJECT_NAME = "Tcl"
OUTPUT_DIRECTORY = ../html/examples/tclexample
-GENERATE_LATEX = NO
+GENERATE_LATEX = YES
GENERATE_MAN = NO
GENERATE_RTF = NO
CASE_SENSE_NAMES = NO
@@ -10,3 +10,5 @@ JAVADOC_AUTOBRIEF = YES
SEARCHENGINE = NO
INLINE_SOURCES = YES
HIDE_UNDOC_MEMBERS = YES
+COMPACT_LATEX = YES
+LATEX_HIDE_INDICES = YES
diff --git a/examples/example.cpp b/examples/example.cpp
index 230d6ec..657c266 100644
--- a/examples/example.cpp
+++ b/examples/example.cpp
@@ -1,8 +1,8 @@
-/** A Test class.
+/** A Example_Test class.
* More details about this class.
*/
-class Test
+class Example_Test
{
public:
/** An example member function.
@@ -11,9 +11,9 @@ class Test
void example();
};
-void Test::example() {}
+void Example_Test::example() {}
/** \example example_test.cpp
* This is an example of how to use the Test class.
* More details about this example.
*/
@@ -11,9 +11,9 @@ class Test
/** \example example_test.cpp
- * This is an example of how to use the Test class.
+ * This is an example of how to use the Example_Test class.
* More details about this example.
*/
diff --git a/examples/include.cpp b/examples/include.cpp
index 674ad13..ba8c054 100644
--- a/examples/include.cpp
+++ b/examples/include.cpp
@@ -1,7 +1,7 @@
/*! A test class. */
-class Test
+class Include_Test
{
public:
/// a member function
@@ -9,12 +9,12 @@ class Test
};
/*! \page example
- * \dontinclude example_test.cpp
+ * \dontinclude include_test.cpp
* Our main function starts like this:
* \skip main
* \until {
* First we create an object \c t of the Test class.
* \skipline Test
* Then we call the example member function
* \line example
* After that our little test routine ends.
@@ -9,12 +9,12 @@ class Test
* \skip main
* \until {
- * First we create an object \c t of the Test class.
- * \skipline Test
+ * First we create an object \c t of the Include_Test class.
+ * \skipline Include_Test
* Then we call the example member function
* \line example